# this file depends on the creation of the correct directories in Makefile

include buildTools.make
include includePath.make

CXXFLAGS_DEBUG = -g3 -Wall -Wno-sign-compare
CXXFLAGS_RELEASE = -O3 -Wall -Wno-sign-compare

VPATH:=$(VPATH):../examples
EXAMPLES:=$(patsubst ../examples/%.cpp, %, $(wildcard ../examples/*.cpp))
EXAMPLES:=$(EXAMPLES) $(patsubst ../examples/XDT/%.cpp, XDT/%, $(wildcard ../examples/XDT/*.cpp))
LIBPATHS = -L"Release" -L"Debug"
DEBUG_LIBS = -lOdemXD
RELEASE_LIBS = -lOdemX

ifdef POCO_BASE
LIBPATHS += -L"$(POCO_BASE)/lib"
DEBUG_LIBS += -lPocoXMLd -lPocoSQLited -lPocoDatad -lPocoFoundationd -liphlpapi 
RELEASE_LIBS += -lPocoXML -lPocoSQLite -lPocoData -lPocoFoundation -liphlpapi

# add POCO's ODBC lib to LIBS if an example needs ODBC support
#DEBUG_LIBS += -lPocoODBCd
#RELEASE_LIBS += -lPocoODBC
endif

debug_examples : $(addprefix Debug/Examples/, $(EXAMPLES))
	@if test -f error.log -a ! -s error.log; then rm error.log; fi
	@if test -f error.log;\
	then echo; echo There where errors during build process:; echo;\
	cat error.log;\
	echo; echo see error.log for detail; echo;\
	fi

Debug/Examples/% : %.cpp 
	@echo Compile $<
	@if $(CXX) $(CXXFLAGS_DEBUG) $(INCLUDEPATHS) $< \
		$(LIBPATHS) -o $@ $(DEBUG_LIBS) 2>>error.log; \
		then echo ok; else echo error; fi

release_examples : $(addprefix Release/Examples/, $(EXAMPLES))
	@if test -f error.log -a ! -s error.log; then rm error.log; fi
	@if test -f error.log;\
	then echo; echo There where errors during build process:; echo;\
	cat error.log;\
	echo; echo see error.log for detail; echo;\
	fi

Release/Examples/% : %.cpp 
	@echo Compile $<
	@if $(CXX) $(CXXFLAGS_RELEASE) $(INCLUDEPATHS) $< \
		$(LIBPATHS) -o $@ $(RELEASE_LIBS) 2>>error.log; \
		then echo ok; else echo error; fi
